==> atlassian-connect-plugin-1.0.0.jar: js/iframe-min/host/main-min.js <==
_AP.define("host/main",["_dollar","_xdm","host/_addons","host/_status_helper","messages/main","_ui-params"],function(f,i,l,b,e,h){var j=["status","statusText","responseText"],k=["Content-Type"],m=(AJS.EventQueue=AJS.EventQueue||[]),a=window.requestAnimationFrame||function(n){setTimeout(n,10)
},d=(window.AJS&&window.AJS.log)||(window.console&&window.console.log)||(function(){});
function c(n){return f("#embedded-"+n)
}function g(s){f.extend(s,h.fromUrl(s.src));
var O=s.ns,n="ap-"+O,o=f("#"+n),t=c(O),L=t.attr("id"),q="channel-"+O,A=s.w||"100%",N=s.h||"0",u=new Date().getTime(),x=!!s.dlg,J=(t.closest(".aui-inline-dialog").length>0),K=!!s.simpleDlg,D=!!s.general,B=s.productCtx,w;
function I(P,Q){Q=f.extend(Q||{},{moduleKey:O});
m.push({name:P,properties:Q})
}var E=setTimeout(function(){E=null;
b.showloadTimeoutStatus(o);
var P=o.find(".ap-load-timeout");
P.find("a.ap-btn-cancel").click(function(){b.showLoadErrorStatus(o);
y.trigger(x?"ra.dialog.close":"ra.iframe.destroy")
});
M();
I("plugin.iframetimedout",{elapsed:new Date().getTime()-u})
},20000);
function G(){if(E){clearTimeout(E);
E=null
}}function z(){return y.data("ra.dialog.buttons")
}function v(P){return y.data("ra.dialog.buttons").getButton(P)
}var p=new i(f,{remote:s.src,remoteKey:s.key,container:L,channel:q,props:{width:A,height:N}},{remote:["dialogMessage","setWorkflowConfigurationMessage"],local:{init:function(){if(!w){w=true;
G();
t.addClass("iframe-init");
var P=new Date().getTime()-u;
b.showLoadedStatus(o);
M();
y.trigger("ra.iframe.init");
I("plugin.iframeinited",{elapsed:P})
}},resize:r(function(Q,P){if(!x){f("iframe",t).css({width:Q,height:P});
if(J){_AP.require(["inline-dialog"],function(R){R.resizeInlineDialog(t,Q,P)
})
}}}),sizeToParent:r(function(){if(D){F.addClass("full-size-general-page");
function P(){var Q=f(document).height()-AJS.$("#header > nav").outerHeight()-AJS.$("#footer").outerHeight()-20;
f("iframe",t).css({width:"100%",height:Q+"px"})
}f(window).on("resize",P);
P()
}else{F.addClass("full-size-general-page-fail")
}}),getLocation:function(){return window.location.href
},getUser:function(){var P=AJS.Meta,Q=P?P.get("remote-user-fullname"):null;
if(!Q){Q=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!Q){Q=f("a#user-menu-link").attr("title")
}return{fullName:Q,id:s.uid,key:s.ukey}
},getTimeZone:function(){return s.data.timeZone
},showMessage:function(R,S,P,Q){return e.showMessage(R,S,P,Q)
},clearMessage:function(P){return e.clearMessage(P)
},setDialogButtonEnabled:function(Q,P){var R=v(Q);
if(R){R.setEnabled(P)
}},isDialogButtonEnabled:function(P,R){var Q=v(P);
R(Q?Q.isEnabled():void 0)
},createDialog:function(P){_AP.require("dialog",function(Q){Q.create(s.key,B,P)
})
},closeDialog:function(){_AP.require("dialog",function(P){P.close()
})
},hideInlineDialog:function(){_AP.require(["inline-dialog"],function(P){P.hideInlineDialog(t,y)
})
},request:function(U,W,T){var S=s.cp+U.url;
function P(Y){var X={headers:{}};
f.each(j,function(aa,Z){X[Z]=Y[Z]
});
f.each(k,function(aa,Z){X.headers[Z]=Y.getResponseHeader(Z)
});
return X
}function R(X,Z,Y){W([X,Z,P(Y)])
}function Q(Y,Z,X){T([P(Y),Z,X])
}var V={};
f.each(U.headers||{},function(Y,X){V[Y.toLowerCase()]=X
});
f.ajax({url:S,type:U.type||"GET",data:U.data,dataType:"text",contentType:U.contentType,headers:{Accept:V.accept||"*/*","AP-Client-Key":s.key}}).then(R,Q)
},getWorkflowConfiguration:function(Q,S){if(!/^[\w|-]+$/.test(Q)){throw new Error("Invalid workflow ID")
}var R,P=f("#postFunction\\.config-"+Q)[0];
if(P&&P.id.match(/postFunction\.config\-/).length===1){R=f(P).val()
}else{throw ("Workflow configuration not found")
}S(R)
},saveMacro:function(P){_AP.require("confluence/macro/editor",function(Q){Q.saveMacro(P)
})
},closeMacroEditor:function(){_AP.require("confluence/macro/editor",function(P){P.close()
})
},getMacroData:function(P){_AP.require("confluence/macro/editor",function(Q){Q.getMacroData(P)
})
}}});
b.showLoadingStatus(o);
var y=t.parents(".ap-servlet-placeholder"),F=f("iframe",t);
F.data("ap-rpc",p);
function M(){var P=f(".ap-stats",o);
P.removeClass("hidden");
if(K){var Q=y.parent().height();
F.parents(".ap-servlet-placeholder, .ap-container").height(Q);
var R=F.parents(".ap-container").height(),S=R;
if(P.find(".ap-status:visible").length>0){S-=P.outerHeight(true)
}F.height(S);
t.height(S)
}}M();
function r(P,R){var Q;
return function(){var S=this,U=[].slice.call(arguments);
function T(){Q=null;
P.apply(S,U)
}if(Q){clearTimeout(Q)
}Q=setTimeout(T,R||50)
}
}var C=z();
if(C){C.each(function(P,Q){Q.click(function(R,S){if(w){p.dialogMessage(P,S)
}else{S(true)
}})
})
}var H=false;
f(document).delegate("#add_submit, #update_submit","click",function(P){if(!H){P.preventDefault();
p.setWorkflowConfigurationMessage(function(Q){if(Q.valid){f("#postFunction\\.config-"+Q.uuid).val(Q.value);
H=true;
f(P.target).click()
}})
}});
l.get(s.key).add(p);
y.bind("ra.iframe.destroy",function(){l.get(s.key).remove(p);
p.destroy()
});
y.trigger("ra.iframe.create")
}return function(o){var p=0;
function n(){if(c(o.ns).length===0&&p<10){setTimeout(function(){p++;
n()
},50);
return
}c(o.ns).find("iframe").each(function(q,r){var s=f(r).data("ap-rpc");
if(s){s.destroy()
}});
g(o)
}if(f.isReady){a(n)
}else{AJS.toInit(function(){if(AJS.Confluence&&AJS.Confluence.EditorLoader&&AJS.Confluence.EditorLoader.load){AJS.Confluence.EditorLoader.load(n,n)
}else{n()
}})
}}
});
if(!_AP.create){_AP.require(["host/main"],function(a){_AP.create=a
})
};

==> atlassian-connect-plugin-1.0.2.jar: js/iframe-min/host/main-min.js <==
_AP.define("host/main",["_dollar","_xdm","host/_addons","host/_status_helper","messages/main","_ui-params"],function(f,i,l,b,e,h){var j=["status","statusText","responseText"],k=["Content-Type"],m=(AJS.EventQueue=AJS.EventQueue||[]),a=window.requestAnimationFrame||function(n){setTimeout(n,10)
},d=(window.AJS&&window.AJS.log)||(window.console&&window.console.log)||(function(){});
function c(n){return f("#embedded-"+n)
}function g(s){f.extend(s,h.fromUrl(s.src));
var O=s.ns,n="ap-"+O,o=f("#"+n),t=c(O),K=t.attr("id"),q="channel-"+O,A=s.w||"100%",M=s.h||"0",u=new Date().getTime(),x=!!s.dlg,I=(t.closest(".aui-inline-dialog").length>0),J=!!s.simpleDlg,D=!!s.general,B=s.productCtx,w;
function H(P,Q){Q=f.extend(Q||{},{moduleKey:O});
m.push({name:P,properties:Q})
}var E=setTimeout(function(){E=null;
b.showloadTimeoutStatus(o);
var P=o.find(".ap-load-timeout");
P.find("a.ap-btn-cancel").click(function(){b.showLoadErrorStatus(o);
y.trigger(x?"ra.dialog.close":"ra.iframe.destroy")
});
L();
H("plugin.iframetimedout",{elapsed:new Date().getTime()-u})
},20000);
function G(){if(E){clearTimeout(E);
E=null
}}function z(){return y.data("ra.dialog.buttons")
}function v(P){return y.data("ra.dialog.buttons").getButton(P)
}function N(){return JSON.parse(B)
}var p=new i(f,{remote:s.src,remoteKey:s.key,container:K,channel:q,props:{width:A,height:M}},{remote:["dialogMessage","setWorkflowConfigurationMessage"],local:{init:function(){if(!w){w=true;
G();
t.addClass("iframe-init");
var P=new Date().getTime()-u;
b.showLoadedStatus(o);
L();
y.trigger("ra.iframe.init");
H("plugin.iframeinited",{elapsed:P})
}},resize:r(function(Q,P){if(!x){f("iframe",t).css({width:Q,height:P});
if(I){_AP.require(["inline-dialog"],function(R){R.resizeInlineDialog(t,Q,P)
})
}}}),sizeToParent:r(function(){if(D){F.addClass("full-size-general-page");
function P(){var Q=f(document).height()-AJS.$("#header > nav").outerHeight()-AJS.$("#footer").outerHeight()-20;
f("iframe",t).css({width:"100%",height:Q+"px"})
}f(window).on("resize",P);
P()
}else{F.addClass("full-size-general-page-fail")
}}),getLocation:function(){return window.location.href
},getUser:function(){var P=AJS.Meta,Q=P?P.get("remote-user-fullname"):null;
if(!Q){Q=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!Q){Q=f("a#user-menu-link").attr("title")
}return{fullName:Q,id:s.uid,key:s.ukey}
},getTimeZone:function(){return s.data.timeZone
},showMessage:function(R,S,P,Q){return e.showMessage(R,S,P,Q)
},clearMessage:function(P){return e.clearMessage(P)
},setDialogButtonEnabled:function(Q,P){var R=v(Q);
if(R){R.setEnabled(P)
}},isDialogButtonEnabled:function(P,R){var Q=v(P);
R(Q?Q.isEnabled():void 0)
},createDialog:function(P){_AP.require("dialog",function(Q){Q.create(s.key,B,P)
})
},closeDialog:function(){_AP.require("dialog",function(P){P.close()
})
},hideInlineDialog:function(){_AP.require(["inline-dialog"],function(P){P.hideInlineDialog(t,y)
})
},request:function(U,W,T){var S=s.cp+U.url;
function P(Y){var X={headers:{}};
f.each(j,function(aa,Z){X[Z]=Y[Z]
});
f.each(k,function(aa,Z){X.headers[Z]=Y.getResponseHeader(Z)
});
return X
}function R(X,Z,Y){W([X,Z,P(Y)])
}function Q(Y,Z,X){T([P(Y),Z,X])
}var V={};
f.each(U.headers||{},function(Y,X){V[Y.toLowerCase()]=X
});
f.ajax({url:S,type:U.type||"GET",data:U.data,dataType:"text",contentType:U.contentType,headers:{Accept:V.accept||"*/*","AP-Client-Key":s.key}}).then(R,Q)
},getWorkflowConfiguration:function(P){AP.require("jira/workflow-post-function",function(R){var Q=N()["postFunction.id"];
R.getConfiguration(Q,P)
})
},saveMacro:function(P){_AP.require("confluence/macro/editor",function(Q){Q.saveMacro(P)
})
},closeMacroEditor:function(){_AP.require("confluence/macro/editor",function(P){P.close()
})
},getMacroData:function(P){_AP.require("confluence/macro/editor",function(Q){Q.getMacroData(P)
})
}}});
b.showLoadingStatus(o);
var y=t.parents(".ap-servlet-placeholder"),F=f("iframe",t);
F.data("ap-rpc",p);
function L(){var P=f(".ap-stats",o);
P.removeClass("hidden");
if(J){var Q=y.parent().height();
F.parents(".ap-servlet-placeholder, .ap-container").height(Q);
var R=F.parents(".ap-container").height(),S=R;
if(P.find(".ap-status:visible").length>0){S-=P.outerHeight(true)
}F.height(S);
t.height(S)
}}L();
function r(P,R){var Q;
return function(){var S=this,U=[].slice.call(arguments);
function T(){Q=null;
P.apply(S,U)
}if(Q){clearTimeout(Q)
}Q=setTimeout(T,R||50)
}
}var C=z();
if(C){C.each(function(P,Q){Q.click(function(R,S){if(w){p.dialogMessage(P,S)
}else{S(true)
}})
})
}_AP.require("jira/workflow-post-function",function(Q){if(Q.isOnWorkflowPostFunctionPage()){var P=N()["postFunction.id"];
Q.registerSubmissionButton(p,P)
}});
l.get(s.key).add(p);
y.bind("ra.iframe.destroy",function(){l.get(s.key).remove(p);
p.destroy()
});
y.trigger("ra.iframe.create")
}return function(o){var p=0;
function n(){if(c(o.ns).length===0&&p<10){setTimeout(function(){p++;
n()
},50);
return
}c(o.ns).find("iframe").each(function(q,r){var s=f(r).data("ap-rpc");
if(s){s.destroy()
}});
g(o)
}if(f.isReady){a(n)
}else{AJS.toInit(function(){if(AJS.Confluence&&AJS.Confluence.EditorLoader&&AJS.Confluence.EditorLoader.load){AJS.Confluence.EditorLoader.load(n,n)
}else{n()
}})
}}
});
if(!_AP.create){_AP.require(["host/main"],function(a){_AP.create=a
})
};
